# remirepo/fedora spec file for libxlswriter
#
# Copyright (c) 2018-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%global gh_commit   559e391cd182599448121a528b8f4b94fda3660d
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    jmcnamara
%global gh_project  libxlsxwriter
%global libname     %{gh_project}

Name:          %{libname}
Summary:       A C library for creating Excel XLSX files
Version:       0.9.4
Release:       1%{?dist}
License:       BSD

URL:           https://github.com/%{gh_owner}/%{gh_project}/
Source0:       https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{gh_short}.tar.gz

Patch0:        %{libname}-el6.patch

BuildRequires: gcc
BuildRequires: gcc-c++
# see https://github.com/jmcnamara/libxlsxwriter/issues/168
%if 0%{?rhel} == 6 || 0%{?rhel} == 7
BuildRequires: cmake3
%else
BuildRequires: cmake >= 2.8.7
%endif
BuildRequires: zlib-devel



%description
Libxlsxwriter is a C library that can be used to write text, numbers, formulas
and hyperlinks to multiple worksheets in an Excel 2007+ XLSX file.

It supports features such as:

* 100% compatible Excel XLSX files.
* Full Excel formatting.
* Merged cells.
* Defined names.
* Autofilters.
* Charts.
* Data validation and drop down lists.
* Worksheet PNG/JPEG images.
* Memory optimization mode for writing large files.
* Source code available on GitHub.
* FreeBSD license.
* ANSI C.
* Works with GCC, Clang, Xcode, MSVC 2015, ICC, TCC, MinGW, MingGW-w64/32.
* Works on Linux, FreeBSD, OpenBSD, OS X, iOS and Windows.
  Also works on MSYS/MSYS2 and Cygwin.
* Compiles for 32 and 64 bit.
* Compiles and works on big and little endian systems.
* The only dependency is on zlib.


%package devel
Summary:    Header files and development libraries for %{name}
Group:      Development/Libraries
Requires:   %{name}%{?_isa} = %{version}-%{release}

%description devel
This package contains the header files and development libraries
for %{name}.


%prep
%setup -q -n %{gh_project}-%{gh_commit}
%if 0%{?rhel} == 6
%patch0 -p1 -b .el6
%endif


%build
%if 0%{?rhel} == 6 || 0%{?rhel} == 7
%cmake3 -DBUILD_TESTS=ON
%else
%cmake -DBUILD_TESTS=ON
%endif

make %{_smp_mflags}


%check
make test


%install
make install DESTDIR="%{buildroot}"


%if 0%{?fedora} < 28 && 0%{?rhel} < 8
%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif


%files
%{!?_licensedir:%global license %%doc}
%license License.txt
%{_libdir}/%{libname}.so


%files devel
%doc *.md
%doc Changes.txt
%doc examples
%{_includedir}/xls*


%changelog
* Mon Jan 20 2020 Remi Collet <remi@remirepo.net> - 0.9.4-1
- update to 0.9.4

* Tue Jan 14 2020 Remi Collet <remi@remirepo.net> - 0.9.3-1
- update to 0.9.3

* Tue Dec 31 2019 Remi Collet <remi@remirepo.net> - 0.9.1-1
- update to 0.9.1

* Wed Dec 18 2019 Remi Collet <remi@remirepo.net> - 0.8.9-1
- update to 0.8.9

* Mon Nov 18 2019 Remi Collet <remi@remirepo.net> - 0.8.8-1
- update to 0.8.8

* Fri Jun 21 2019 Remi Collet <remi@remirepo.net> - 0.8.7-1
- update to 0.8.7

* Mon Apr  8 2019 Remi Collet <remi@remirepo.net> - 0.8.6-1
- update to 0.8.6

* Mon Feb 11 2019 Remi Collet <remi@remirepo.net> - 0.8.5-1
- update to 0.8.5

* Mon Nov 12 2018 Remi Collet <remi@remirepo.net> - 0.8.4-1
- update to 0.8.4

* Tue Oct  2 2018 Remi Collet <remi@remirepo.net> - 0.8.3-1
- update to 0.8.3

* Mon Sep 17 2018 Remi Collet <remi@remirepo.net> - 0.8.2-1
- update to 0.8.2

* Sun Sep 16 2018 Remi Collet <remi@remirepo.net> - 0.8.1-1
- update to 0.8.1

* Wed Sep 12 2018 Remi Collet <remi@remirepo.net> - 0.8.0-1
- update to 0.8.0

* Sun Sep  2 2018 Remi Collet <remi@remirepo.net> - 0.7.9-1
- update to 0.7.9

* Fri Aug 31 2018 Remi Collet <remi@remirepo.net> - 0.7.8-1
- update to 0.7.8

* Wed Aug 22 2018 Remi Collet <remi@remirepo.net> - 0.7.7-2
- F29 cleanup

* Fri May 25 2018 Remi Collet <remi@remirepo.net> - 0.7.7-1
- update to 0.7.7
- drop workaround for PR merged upstream

* Fri Apr 27 2018 Remi Collet <remi@remirepo.net> - 0.7.6-1
- initial package
- open https://github.com/jmcnamara/libxlsxwriter/issues/166 library layout
  fixed by https://github.com/jmcnamara/libxlsxwriter/pull/170
- open https://github.com/jmcnamara/libxlsxwriter/issues/167 soname
- open https://github.com/jmcnamara/libxlsxwriter/issues/168 cmake version
  fixed by https://github.com/jmcnamara/libxlsxwriter/pull/169
